all.Digss<-function(){
     cat("\n")
     note_for_Dig_input()
     cat("\n")
     note_for_close_window()
     DigSSpar<-data.frame(parameter=c("Gender","age (yr)","bw (kg)","scr (mg/dL)","D (mg)","tau (hr)","c (ng/mL)"),value=c(0))
     DigSSpar<-edit(DigSSpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(DigSSpar);cat("\n\n")
##     DigSSpar<-ycheck(DigSSpar)
     cat("\n")
     Dig.ss(DigSSpar[7,2],DigSSpar[6,2],DigSSpar[5,2],DigSSpar[4,2],DigSSpar[3,2],DigSSpar[2,2],DigSSpar[1,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     note_for_Dig_output()
     ### show(samplesStats("*"))
     cat("\n") 
     C<-Digcpr(DigSSpar[5,2],DigSSpar[6,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(Parameters=c("Cmss_obs (ng/mL)","Cmss_pr (ng/mL)"),Values=c(DigSSpar[7,2],C))
     cat("\n\n");show(coutput);cat("\n") 
     Dig.more()
}